@@ -7,25 +7,26 @@ use utf8;
 use lib '../../lib';
 use Term::Choose qw( choose );
 
-use lib 't/';
-use Term_Choose_Testdata;
+use FindBin qw( $RealBin );
+use lib $RealBin;
+use Data_Test_Arguments;
 
 
 choose( [] );
 choose( [], {} );
 
-my $valid_values = Term_Choose_Testdata::valid_values();
+my $valid_values = Data_Test_Arguments::valid_values();
 for my $opt ( sort keys %$valid_values ) {
     for my $val ( @{$valid_values->{$opt}}, undef ) {
         choose( [], { $opt => $val } );
     }
 }
 
-my $mixed_options_1 = Term_Choose_Testdata::mixed_options_1();
+my $mixed_options_1 = Data_Test_Arguments::mixed_options_1();
 choose( [], $mixed_options_1 );
 
-my $mixed_options_2 = Term_Choose_Testdata::mixed_options_2();
+my $mixed_options_2 = Data_Test_Arguments::mixed_options_2();
 choose( [], $mixed_options_1 );
 
 
-say "<End_func_chse_arg_test>";
+say "<End_fc_va>";
