@@ -7,8 +7,9 @@ use utf8;
 use lib '../../lib';
 use Term::Choose qw( choose );
 
-use lib 't/';
-use Term_Choose_Testdata;
+use FindBin qw( $RealBin );
+use lib $RealBin;
+use Data_Test_Arguments;
 
 
 eval { choose(           ); 1 } and die 'choose();';
@@ -28,18 +29,18 @@ eval { choose( [], []    ); 1 } and die 'choose( [], [] );';
 eval { choose( [], 'b'   ); 1 } and die 'choose( [], "b" );';
 
 
-my $valid_values = Term_Choose_Testdata::invalid_values();
+my $valid_values = Data_Test_Arguments::invalid_values();
 for my $opt ( sort keys %$valid_values ) {
     for my $val ( @{$valid_values->{$opt}} ) {
         eval { choose( [], { $opt => $val } ); 1 } and die "choose( { $opt => $val } );";
     }
 }
 
-my $mixed_options_1 = Term_Choose_Testdata::mixed_invalid_1();
+my $mixed_options_1 = Data_Test_Arguments::mixed_invalid_1();
 eval { choose( [], $mixed_options_1 ); 1 } and die 'choose( >>> );';
 
-my $mixed_options_2 = Term_Choose_Testdata::mixed_invalid_2();
+my $mixed_options_2 = Data_Test_Arguments::mixed_invalid_2();
 eval { choose( [], $mixed_options_1 ); 1 } and die 'choose( <<< );';
 
 
-say "<End_func_chse_invalid_arg_test>";
+say "<End_fc_ia>";
